@@ -4,7 +4,7 @@
 //  Tree control used for the survey tree.
 //
 //  Copyright (C) 2001, Mark R. Shinwell.
-//  Copyright (C) 2002,2006,2018 Olly Betts
+//  Copyright (C) 2002,2006,2018,2025 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -48,11 +48,11 @@ public:
 
 class AvenTreeCtrl : public wxTreeCtrl {
     MainFrm* m_Parent;
-    bool m_Enabled;
+    bool m_Enabled = false;
     wxTreeItemId m_LastItem;
     wxColour m_BackgroundColour;
-    bool m_SelValid;
-    const TreeData* menu_data;
+    bool m_SelValid = false;
+    const TreeData* menu_data = nullptr;
     wxTreeItemId menu_item;
 
     SurveyFilter filter;
@@ -75,6 +75,7 @@ public:
     void OnHide(wxCommandEvent& e);
     void OnShow(wxCommandEvent& e);
     void OnHideSiblings(wxCommandEvent& e);
+    void OnFind(wxCommandEvent& e);
     void OnStateClick(wxTreeEvent& e);
 
     bool GetSelectionData(wxTreeItemData**) const;
