@@ -4,7 +4,7 @@
 //  Header file for the GLA abstraction layer.
 //
 //  Copyright (C) 2002 Mark R. Shinwell.
-//  Copyright (C) 2003,2004,2005,2006,2007,2011,2012,2014,2017,2018 Olly Betts
+//  Copyright (C) 2003-2025 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -30,11 +30,22 @@
 using namespace std;
 
 #include "wx.h"
-#include "aventypes.h"
 #include "vector3.h"
 
 #include "glbitmapfont.h"
 
+#ifdef HAVE_GL_GL_H
+# include <GL/gl.h>
+#elif defined HAVE_OPENGL_GL_H
+# include <OpenGL/gl.h>
+#endif
+
+#ifdef HAVE_GL_GLU_H
+# include <GL/glu.h>
+#elif defined HAVE_OPENGL_GLU_H
+# include <OpenGL/glu.h>
+#endif
+
 class GfxCore;
 
 string GetGLSystemDescription();
@@ -120,6 +131,8 @@ class GLACanvas : public wxGLCanvas {
     double m_Scale = 0.0;
     Vector3 m_Translation;
 
+    double z_stretch = 1.0;
+
     BitmapFont m_Font;
 
     GLUquadric* m_Quadric = nullptr;
@@ -283,6 +296,8 @@ public:
     bool Transform(const Vector3 & v, glaCoord* x_out, glaCoord* y_out, glaCoord* z_out) const;
     void ReverseTransform(double x, double y, glaCoord* x_out, glaCoord* y_out, glaCoord* z_out) const;
 
+    void SetZStretch(double z_stretch_) { z_stretch = z_stretch_; }
+
     int GetFontSize() const { return m_Font.get_font_size(); }
 
     void ToggleSmoothShading();
