@@ -30,7 +30,7 @@
 #include "aboutdlg.h"
 
 #include "message.h"
-#include "img_hosted.h"
+#include "img_for_survex.h"
 #include "printing.h"
 #include "filename.h"
 #include "useful.h"
@@ -42,6 +42,8 @@
 #include <wx/imaglist.h>
 #include <wx/process.h>
 #include <wx/regex.h>
+#include <wx/srchctrl.h>
+#include <wx/spinctrl.h>
 #ifdef USING_GENERIC_TOOLBAR
 # include <wx/sysopt.h>
 #endif
@@ -83,8 +85,6 @@
 #include "../lib/icons/pres_ff.xpm"
 #include "../lib/icons/pres_fff.xpm"
 #include "../lib/icons/pres_stop.xpm"
-#include "../lib/icons/find.xpm"
-#include "../lib/icons/hideresults.xpm"
 #include "../lib/icons/survey_tree.xpm"
 #include "../lib/icons/pres_tree.xpm"
 #undef static
@@ -220,7 +220,7 @@ static void write_double(double d, FILE * fh) {
     size_t l = strlen(buf);
     while (l > 1 && buf[l - 1] == '0') --l;
     if (l > 1 && buf[l - 1] == '.') --l;
-    fwrite(buf, l, 1, fh);
+    FWRITE_(buf, l, 1, fh);
 }
 
 class AvenPresList : public wxListCtrl {
@@ -368,7 +368,7 @@ class AvenPresList : public wxListCtrl {
 
 	    FILE * fh_pres = wxFopen(fnm, wxT("w"));
 	    if (!fh_pres) {
-		wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/110), fnm.c_str()));
+		wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/7), fnm.c_str()));
 		return;
 	    }
 	    vector<PresentationMark>::const_iterator i;
@@ -406,13 +406,13 @@ class AvenPresList : public wxListCtrl {
 	    FILE * fh_pres = wxFopen(fnm, wxT("r"));
 	    if (!fh_pres) {
 		wxString m;
-		m.Printf(wmsg(/*Couldn’t open file “%s”*/24), fnm.c_str());
+		m.Printf(wmsg(/*Couldn’t open file “%s”*/1), fnm.c_str());
 		wxGetApp().ReportError(m);
 		return false;
 	    }
 	    DeleteAllItems();
 	    long item = 0;
-	    while (!feof(fh_pres)) {
+	    while (!FEOF(fh_pres)) {
 		char buf[4096];
 		size_t i = 0;
 		while (i < sizeof(buf) - 1) {
@@ -493,9 +493,7 @@ END_EVENT_TABLE()
 BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_TEXT(textctrl_FIND, MainFrm::OnFind)
     EVT_TEXT_ENTER(textctrl_FIND, MainFrm::OnGotoFound)
-    EVT_MENU(wxID_FIND, MainFrm::OnGotoFound)
-    EVT_MENU(button_HIDE, MainFrm::OnHide)
-    EVT_UPDATE_UI(button_HIDE, MainFrm::OnHideUpdate)
+    EVT_SPINCTRLDOUBLE(spinctrl_Z_STRETCH, MainFrm::OnZStretch)
     EVT_IDLE(MainFrm::OnIdle)
 
     EVT_MENU(wxID_OPEN, MainFrm::OnOpen)
@@ -1029,13 +1027,27 @@ void MainFrm::MakeToolBar()
     toolbar->AddTool(wxID_STOP, wxT("Stop"), TOOL(pres_stop), wxT("Stop"));
 
     toolbar->AddSeparator();
-    m_FindBox = new wxTextCtrl(toolbar, textctrl_FIND, wxString(), wxDefaultPosition,
-			       wxDefaultSize, wxTE_PROCESS_ENTER);
+    m_FindBox = new wxSearchCtrl(toolbar, textctrl_FIND);
+    m_FindBox->SetSize(160, -1);
+    // TRANSLATORS: Placeholder text in aven's station search control.
+    m_FindBox->SetDescriptiveText(wmsg(/*Find stations*/333));
     toolbar->AddControl(m_FindBox);
-    /* TRANSLATORS: "Find stations" button tooltip */
-    toolbar->AddTool(wxID_FIND, wmsg(/*Find*/332), TOOL(find)/*, "Search for station name"*/);
-    /* TRANSLATORS: "Hide stations" button default tooltip */
-    toolbar->AddTool(button_HIDE, wmsg(/*Hide*/333), TOOL(hideresults)/*, "Hide search results"*/);
+    // TRANSLATORS: Tooltip for aven's station search control.
+    GetToolBar()->SetToolShortHelp(textctrl_FIND,
+				   wmsg(/*Station name search (substring or wildcard)*/533));
+
+    auto z_stretch = new wxSpinCtrlDouble(toolbar, spinctrl_Z_STRETCH,
+					  wxEmptyString,
+					  wxDefaultPosition, wxDefaultSize,
+					  wxSP_ARROW_KEYS|wxALIGN_RIGHT);
+    z_stretch->SetValue(1.0);
+    z_stretch->SetRange(0.1, 10.0);
+    z_stretch->SetIncrement(0.1);
+    toolbar->AddSeparator();
+    toolbar->AddControl(z_stretch);
+    // TRANSLATORS: Tooltip for Z exaggeration control.
+    GetToolBar()->SetToolShortHelp(spinctrl_Z_STRETCH,
+				   wmsg(/*Z exaggeration factor*/535));
 
     toolbar->Realize();
 }
@@ -1534,7 +1546,7 @@ void MainFrm::OnScreenshot(wxCommandEvent&)
 	    png_handled = true;
 	}
 	if (!m_Gfx->SaveScreenshot(dlg.GetPath(), wxBITMAP_TYPE_PNG)) {
-	    wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/110), dlg.GetPath().c_str()));
+	    wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/7), dlg.GetPath().c_str()));
 	}
     }
 }
@@ -1981,12 +1993,12 @@ void MainFrm::TreeItemSearch(const wxTreeItemData* item)
     const TreeData* data = static_cast<const TreeData*>(item);
     if (!data) return;
 
+    pending_find = PENDING_FIND_AND_GO;
     if (data->IsStation()) {
 	m_FindBox->ChangeValue(data->GetLabel()->GetText());
     } else {
 	m_FindBox->ChangeValue(data->GetSurvey() + ".*");
     }
-    pending_find = PENDING_FIND_AND_GO;
 }
 
 void MainFrm::OnPresNew(wxCommandEvent&)
@@ -2120,8 +2132,7 @@ PresentationMark MainFrm::GetPresMark(int which)
 void MainFrm::RestrictTo(const wxString & survey)
 {
     // The station names will change, so clear the current search.
-    wxCommandEvent dummy;
-    OnHide(dummy);
+    m_FindBox->SetValue(wxString());
 
     wxString new_prefix;
     if (!survey.empty()) {
@@ -2227,7 +2238,7 @@ void MainFrm::OnPresExportMovieUpdate(wxUpdateUIEvent& event)
 
 void MainFrm::OnFind(wxCommandEvent&)
 {
-    pending_find = PENDING_FIND;
+    if (pending_find == PENDING_FIND_NONE) pending_find = PENDING_FIND;
 }
 
 void MainFrm::OnIdle(wxIdleEvent&)
@@ -2242,6 +2253,7 @@ void MainFrm::DoFind()
     wxBusyCursor hourglass;
     // Find stations specified by a string or regular expression pattern.
 
+    bool substring = true;
     wxString pattern = m_FindBox->GetValue();
     if (pattern.empty()) {
 	// Hide any search result highlights.
@@ -2258,7 +2270,6 @@ void MainFrm::DoFind()
 	    re_flags |= wxRE_ICASE;
 	}
 
-	bool substring = true;
 	if (false /*m_RegexpCheckBox->GetValue()*/) {
 	    re_flags |= wxRE_EXTENDED;
 	} else if (true /* simple glob-style */) {
@@ -2337,14 +2348,26 @@ void MainFrm::DoFind()
     m_Gfx->UpdateBlobs();
     m_Gfx->ForceRefresh();
 
-    if (!m_NumHighlighted) {
-	GetToolBar()->SetToolShortHelp(button_HIDE, wmsg(/*No matches were found.*/328));
-    } else {
-	/* TRANSLATORS: "Hide stations" button tooltip when stations are found
+    if (m_NumHighlighted) {
+	pattern = m_FindBox->GetValue();
+	/* TRANSLATORS: Find station tooltip when stations are found.  %d is
+	 * replaced by the number of matching stations and %s%s%s by the
+	 * pattern searched for.
 	 */
-	GetToolBar()->SetToolShortHelp(button_HIDE, wxString::Format(wmsg(/*Hide %d found stations*/334).c_str(), m_NumHighlighted));
+	GetToolBar()->SetToolShortHelp(textctrl_FIND, wxString::Format(wmsg(/*%d stations match %s%s%s*/334).c_str(),
+								       m_NumHighlighted,
+								       substring ? "*" : "",
+								       m_FindBox->GetValue(),
+								       substring ? "*" : ""));
+    } else if (pattern.empty()) {
+	// TRANSLATORS: Tooltip for aven's station search control.
+	GetToolBar()->SetToolShortHelp(textctrl_FIND,
+				       wmsg(/*Station name search (substring or wildcard)*/533));
+    } else {
+	GetToolBar()->SetToolShortHelp(textctrl_FIND, wmsg(/*No matches were found.*/328));
     }
-    if (pending_find == PENDING_FIND_AND_GO) {
+
+    if (pending_find == PENDING_FIND_AND_GO && !pattern.empty()) {
 	wxCommandEvent dummy;
 	OnGotoFound(dummy);
     }
@@ -2383,15 +2406,12 @@ void MainFrm::OnGotoFound(wxCommandEvent&)
     m_Gfx->SetFocus();
 }
 
-void MainFrm::OnHide(wxCommandEvent&)
+void MainFrm::OnZStretch(wxSpinDoubleEvent& event)
 {
-    m_FindBox->SetValue(wxString());
-    GetToolBar()->SetToolShortHelp(button_HIDE, wmsg(/*Hide*/333));
-}
-
-void MainFrm::OnHideUpdate(wxUpdateUIEvent& ui)
-{
-    ui.Enable(m_NumHighlighted != 0);
+    m_Gfx->SetZStretch(event.GetValue());
+    if (static_cast<wxWindow*>(event.GetEventObject())->HasFocus()) {
+	m_Gfx->SetFocus();
+    }
 }
 
 void MainFrm::OnViewSidePanel(wxCommandEvent&)
